"""Public Schemathesis errors."""

from schemathesis.core.errors import (
    HookError,
    IncorrectUsage,
    InfiniteRecursiveReference,
    InternalError,
    InvalidHeadersExample,
    InvalidRateLimit,
    InvalidRegexPattern,
    InvalidRegexType,
    InvalidSchema,
    InvalidStateMachine,
    InvalidTransition,
    LoaderError,
    NoLinksFound,
    OperationNotFound,
    SchemathesisError,
    SerializationError,
    SerializationNotPossible,
    TransitionValidationError,
    UnboundPrefix,
    UnresolvableReference,
)

__all__ = [
    "HookError",
    "IncorrectUsage",
    "InfiniteRecursiveReference",
    "InternalError",
    "InvalidHeadersExample",
    "InvalidRateLimit",
    "InvalidRegexPattern",
    "InvalidRegexType",
    "InvalidSchema",
    "InvalidStateMachine",
    "InvalidTransition",
    "LoaderError",
    "OperationNotFound",
    "NoLinksFound",
    "SchemathesisError",
    "SerializationError",
    "SerializationNotPossible",
    "TransitionValidationError",
    "UnboundPrefix",
    "UnresolvableReference",
]
